@@ -144,6 +144,22 @@ class AssertTest extends BaseTestCase
             array('isInstanceOfAny', array(new Exception(), array('ArrayAccess', 'Countable')), false),
             array('isInstanceOfAny', array(123, array('stdClass')), false),
             array('isInstanceOfAny', array(array(), array('stdClass')), false),
+            array('isAOf', array('stdClass', 'stdClass'), true),
+            array('isAOf', array('stdClass', 123), false),
+            array('isAOf', array('Iterator', 'ArrayIterator'), false),
+            array('isAOf', array(123, 'Iterator'), false),
+            array('isAOf', array(array(), 'Iterator'), false),
+            array('isAnyOf', array('ArrayIterator', array('Iterator', 'ArrayAccess')), true),
+            array('isAnyOf', array('ArrayIterator', array(123)), false),
+            array('isAnyOf', array('Exception', array('Exception', 'Countable')), true),
+            array('isAnyOf', array('Exception', array('ArrayAccess', 'Countable')), false),
+            array('isAnyOf', array(123, array('stdClass')), false),
+            array('isAnyOf', array(array(), array('stdClass')), false),
+            array('isNotA', array('stdClass', 'stdClass'), false),
+            array('isNotA', array('stdClass', 123), false),
+            array('isNotA', array('Iterator', 'ArrayIterator'), true),
+            array('isNotA', array(123, 'Iterator'), true),
+            array('isNotA', array(array(), 'Iterator'), true),
             array('true', array(true), true),
             array('true', array(false), false),
             array('true', array(1), false),
@@ -153,6 +169,11 @@ class AssertTest extends BaseTestCase
             array('false', array(1), false),
             array('false', array(0), false),
             array('false', array(null), false),
+            array('notFalse', array(false), false),
+            array('notFalse', array(true), true),
+            array('notFalse', array(1), true),
+            array('notFalse', array(0), true),
+            array('notFalse', array(null), true),
             array('null', array(null), true),
             array('null', array(false), false),
             array('null', array(0), false),
